@@ -6,6 +6,7 @@ Created on Tue Mar  2 14:29:24 2021
 @author: eduard
 """
 import pandas as pd
+import sys
 
 
 
@@ -20,4 +21,9 @@ def print_HALLO_3():
     print("Hello from print me now 3")     
     
 def print_HALLO_pandas():
-    print(f"Hello, used pandas version = {pd.__version__}")   
\ No newline at end of file
+    print(f"Hello, used pandas version = {pd.__version__}")   
+    
+def print_sys_infos():
+    print(f"Hello, sys.path = {sys.path}")      
+    
+print_sys_infos( ) 
\ No newline at end of file
